@@ -434,12 +434,13 @@ class Model:
                 variable.value = data[variable.name]
             elif 'table' in data:
                 for table in data['table']:
-                    if variable.name in table:
+                    if variable.name in table and variable.value == None:
                         variable.value = table[variable.name]
+                        table.popitem()
         variables = self.variables
         for variable in variables:
             if 'table' in data:
-                n=0
+                n=1
                 for table in data['table']:
                     if variable.name in table:
                         n=n+1
